package Bencher::Scenarios::ShellGuess;

our $DATE = '2021-07-31'; # DATE
our $VERSION = '0.003'; # VERSION

1;
# ABSTRACT: Scenarios to benchmark Shell::Guess

__END__

=pod

=encoding UTF-8

=head1 NAME

Bencher::Scenarios::ShellGuess - Scenarios to benchmark Shell::Guess

=head1 VERSION

This document describes version 0.003 of Bencher::Scenarios::ShellGuess (from Perl distribution Bencher-Scenarios-ShellGuess), released on 2021-07-31.

=head1 DESCRIPTION

This distribution contains the following L<Bencher> scenario modules:

=over

=item * L<Bencher::Scenario::ShellGuess::Overhead>

=item * L<Bencher::Scenario::ShellGuess::running_shell>

=back

=head1 CONTRIBUTOR

=for stopwords perlancar (@pc-office)

perlancar (@pc-office) <perlancar@gmail.com>

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Bencher-Scenarios-ShellGuess>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Bencher-Scenarios-ShellGuess>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Bencher-Scenarios-ShellGuess>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2021, 2017, 2016 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
